@@ -1,5 +1,5 @@
 from dryml.models.tf.base import TrainFunction, Model, \
-    Trainable, ObjectWrapper
+    Trainable, Wrapper
 import dryml.models.tf.keras as keras
 import dryml.models.tf.utils as utils
 
@@ -7,7 +7,7 @@ __all__ = [
     TrainFunction,
     Model,
     Trainable,
-    ObjectWrapper,
+    Wrapper,
     utils,
     keras,
 ]
