@@ -1,9 +1,10 @@
 from dryml.models.tf.keras.base import Model, Trainable, \
-    BasicTraining, BasicEarlyStoppingTraining, \
+    BasicTraining, BasicEarlyStoppingTraining, ModelWrapper, \
     keras_sequential_functional_class, SequentialFunctionalModel
 
 __all__ = [
     Model,
+    ModelWrapper,
     Trainable,
     BasicTraining,
     BasicEarlyStoppingTraining,
